package RT::Queue;


=head2 Templates

Returns an RT::Templates object of all of this queue's templates.

=cut

sub Templates {
    my $self = shift;

    my $templates = RT::Templates->new( $self->CurrentUser );
    my @ids = ();
    my $parents = $self->Genealogie();
    @ids = map { $_->id } @$parents;

    if ( $self->CurrentUserHasRight('ShowTemplate') ) {
        $templates->LimitToQueues( \@ids );
    }

    return ($templates);
}


=head2 CustomField NAME

Load the Ticket Custom Field applied to this Queue named NAME.
Does not load Global custom fields.

=cut

sub CustomField {
    my $self = shift;
    my $name = shift;
    my $cf = RT::CustomField->new($self->CurrentUser);
    $cf->LoadByName(
        Name       => $name,
        LookupType => RT::Ticket->CustomFieldLookupType,
        ObjectId   => $self->id,
    );

    if (! $cf and $RT::Queue::Parent) {
	return $cf->LoadByName(
	    Name       => $name,
	    LookupType => RT::Ticket->CustomFieldLookupType,
	    ObjectId   => $self->getParent->id,
	    );
    }

    return ($cf);
}



=head2 TicketCustomFields

Returns an L<RT::CustomFields> object containing all global and
queue-specific B<ticket> custom fields.

=cut

sub TicketCustomFields {
    my $self = shift;

    my @ids = ();
    my $parents = $self->Genealogie();
    @ids = map { $_->id } @$parents;
    #warn "Avec les ids : ".join(',',@ids)."\n";

    my $cfs = RT::CustomFields->new( $self->CurrentUser );
    if ( $self->CurrentUserHasRight('SeeQueue') ) {
        $cfs->SetContextObject( $self );
        $cfs->LimitToGlobalOrObjectId( @ids);
        $cfs->LimitToLookupType( 'RT::Queue-RT::Ticket' );
        $cfs->ApplySortOrder;
    }
    return ($cfs);
}



=head2 TicketTransactionCustomFields

Returns an L<RT::CustomFields> object containing all global and
queue-specific B<transaction> custom fields.

=cut

sub TicketTransactionCustomFields {
    my $self = shift;

    my @ids = ();
    my $parents = $self->Genealogie();
    @ids = map { $_->id } @$parents;
    #warn "Avec les ids : ".join(',',@ids)."\n";

    my $cfs = RT::CustomFields->new( $self->CurrentUser );
    if ( $self->CurrentUserHasRight('SeeQueue') ) {
        $cfs->SetContextObject( $self );
        $cfs->LimitToGlobalOrObjectId( @ids );
        $cfs->LimitToLookupType( 'RT::Queue-RT::Ticket-RT::Transaction' );
        $cfs->ApplySortOrder;
    }
    return ($cfs);
}


#RT::Base->_ImportOverlays();

1;
